@@ -248,6 +248,8 @@ namespace rocalution
                 {
                     this->z_[i]->MoveToHost();
                 }
+
+                this->precond_->MoveToHost();
             }
         }
     }
@@ -270,6 +272,7 @@ namespace rocalution
                 {
                     this->z_[i]->MoveToAccelerator();
                 }
+                this->precond_->MoveToAccelerator();
             }
         }
     }
