@@ -233,6 +233,7 @@ namespace rocalution
             if(this->precond_ != NULL)
             {
                 this->z_.MoveToHost();
+                this->precond_->MoveToHost();
             }
         }
     }
@@ -252,6 +253,7 @@ namespace rocalution
             if(this->precond_ != NULL)
             {
                 this->z_.MoveToAccelerator();
+                this->precond_->MoveToAccelerator();
             }
         }
     }
